;; Generated package description from consult-flycheck.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "consult-flycheck" "1.1.0.20260330.61817" "Provides the command `consult-flycheck'" '((emacs "29.1") (consult "2.8") (flycheck "35")) :commit "16fa53d2cc31a2689dfb5d012575c81399f6669d" :maintainer '("Daniel Mendler" . "mail@daniel-mendler.de") :keywords '("languages" "tools" "completion") :url "https://github.com/minad/consult-flycheck")
